searchData={"items":[{"type":"task","title":"mix prometheus_telemetry.gen.metrics","doc":"This can be used to generate metrics modules\n\nThe format used is\n```elixir\n : : : :tags: : \n```","ref":"Mix.Tasks.PrometheusTelemetry.Gen.Metrics.html"},{"type":"task","title":"Example - mix prometheus_telemetry.gen.metrics","doc":"```bash\n$ mix prometheus_telemetry.gen.metrics MyApp.Metrics.Type counter:event.name.measurement.count:event.name.count:count:tags:profile:region\n```\n\nThe following metrics have been implemented:\n`counter`, `distribution`, `last_value` and `sum`\n\nWith `distribution` you can also provide a second parameter of milliseconds, seconds or microseconds","ref":"Mix.Tasks.PrometheusTelemetry.Gen.Metrics.html#module-example"},{"type":"function","title":"Mix.Tasks.PrometheusTelemetry.Gen.Metrics.run/1","doc":"","ref":"Mix.Tasks.PrometheusTelemetry.Gen.Metrics.html#run/1"},{"type":"module","title":"PrometheusTelemetry.PeriodicMeasurements.ErlangVM","doc":"Uses the :erlang.statistics method to check the uptime of the Erlang VM and emits a :telemetry event\n  with the most recent reading.","ref":"PrometheusTelemetry.PeriodicMeasurements.ErlangVM.html"},{"type":"function","title":"PrometheusTelemetry.PeriodicMeasurements.ErlangVM.periodic_measurements/0","doc":"","ref":"PrometheusTelemetry.PeriodicMeasurements.ErlangVM.html#periodic_measurements/0"},{"type":"function","title":"PrometheusTelemetry.PeriodicMeasurements.ErlangVM.vm_wall_clock/0","doc":"","ref":"PrometheusTelemetry.PeriodicMeasurements.ErlangVM.html#vm_wall_clock/0"},{"type":"module","title":"PrometheusTelemetry","doc":"","ref":"PrometheusTelemetry.html"},{"type":"module","title":"PrometheusTelemetry - PrometheusTelemetry","doc":"[![Test](https://github.com/theblitzapp/prometheus_telemetry_elixir/actions/workflows/test.yml/badge.svg)](https://github.com/theblitzapp/prometheus_telemetry_elixir/actions/workflows/test.yml)\n[![Credo](https://github.com/theblitzapp/prometheus_telemetry_elixir/actions/workflows/credo.yml/badge.svg)](https://github.com/theblitzapp/prometheus_telemetry_elixir/actions/workflows/credo.yml)\n[![Dialyzer](https://github.com/theblitzapp/prometheus_telemetry_elixir/actions/workflows/dialyzer.yml/badge.svg)](https://github.com/theblitzapp/prometheus_telemetry_elixir/actions/workflows/dialyzer.yml)\n[![Hex version badge](https://img.shields.io/hexpm/v/prometheus_telemetry.svg)](https://hex.pm/packages/prometheus_telemetry)\n\nPrometheusTelemetry is the plumbing for Telemetry.Metrics and allows the\nmetrics passed in to be collected and exported in the format expected\nby the prometheus scraper.\n\nThis supervisor also contains the ability to spawn an exporter which will\nscrape every supervisor running for metrics and will spin up a plug and return\nit at `/metrics` on port 4050 by default, this will work out of the box with umbrella apps as well and allow you to define metrics in each umbrella app","ref":"PrometheusTelemetry.html#module-prometheustelemetry"},{"type":"module","title":"Installation - PrometheusTelemetry","doc":"The package can be installed by adding `prometheus_telemetry` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:prometheus_telemetry, \"~> 0.4\"}\n  ]\nend\n```\n\nDocumentation can be found at  .","ref":"PrometheusTelemetry.html#module-installation"},{"type":"module","title":"Example - PrometheusTelemetry","doc":"We can add this to any application we want:\n\n```elixir\nchildren = [\n  {PrometheusTelemetry, metrics: [\n   MyMetricsModule.metrics()\n  ]}\n]\n```\n\nThen to setup an exporter, on a server application like a phoenix app or pipeline\nwe can setup the exporter which will start the metrics server (by default on port `localhost:4050`):\n\n```elixir\nchildren = [\n  {PrometheusTelemetry,\n    exporter: [enabled?: true],\n    metrics: MyMetricsModule.metrics()\n  }\n]\n```","ref":"PrometheusTelemetry.html#module-example"},{"type":"module","title":"Built-in Metrics - PrometheusTelemetry","doc":"There are built-in metrics for some erlang vm stats, phoenix, absinthe, ecto and oban. To enable them we can use the following modules:\n\n`PrometheusTelemetry.Metrics.{Ecto,Cowboy,Swoosh,Finch,Phoenix,GraphQL,Oban,VM}`\n\n(See [the notes below](#ecto-extras) on conveniences for configuring metrics for Ecto repos.)\n\n```elixir\nchildren = [\n  {PrometheusTelemetry,\n    exporter: [enabled?: true],\n    metrics: [\n      PrometheusTelemetry.Metrics.Ecto.metrics(:my_ecto_app),\n      PrometheusTelemetry.Metrics.Cowboy.metrics(),\n      PrometheusTelemetry.Metrics.Swoosh.metrics(),\n      PrometheusTelemetry.Metrics.Finch.metrics(),\n      PrometheusTelemetry.Metrics.Phoenix.metrics(),\n      PrometheusTelemetry.Metrics.GraphQL.metrics(),\n      PrometheusTelemetry.Metrics.Oban.metrics(),\n      PrometheusTelemetry.Metrics.VM.metrics()\n    ]\n  }\n]\n```","ref":"PrometheusTelemetry.html#module-built-in-metrics"},{"type":"module","title":"Default Config - PrometheusTelemetry","doc":"These are the default config settings, you can override by setting any of them\n\n```\nconfig :prometheus_telemetry,\n  default_millisecond_buckets: [100, 300, 500, 1000, 2000, 5000, 10_000],\n  default_microsecond_buckets: [50_000, 100_000, 250_000, 500_000, 750_000],\n  measurement_poll_period: :timer.seconds(10),\n  ecto_max_query_length: 150,\n  ecto_known_query_module: nil\n```","ref":"PrometheusTelemetry.html#module-default-config"},{"type":"module","title":"Defining Custom Metrics - PrometheusTelemetry","doc":"To define metrics we can create a module to group them like `MyMetricsModule`\n\n```elixir\ndefmodule MyMetricsModule do\n  import Telemetry.Metrics, only: [last_value: 2, counter: 2]\n\n  def metrics do\n    [\n      counter(\n        \"prometheus_name.to_save\", # becomes prometheus_name_to_save in prometheus\n        event_name: [:event_namespace, :my_metric], # telemetry event name\n        measurement: :count, # telemetry event metric\n        description: \"some description\"\n      ),\n\n      last_value(\n        \"my_custom.name\",\n        event_name: [:event_namespace, :last_value],\n        measurement: :total,\n        description: \"my value\",\n        tags: [:custom_metric] # custom metrics to save, derived from :telemetry.execute metadata\n      )\n    ]\n  end\n\n  def inc_to_save do\n    :telemetry.execute([:event_namespace, :my_metric], %{count: 1})\n  end\n\n  def set_custom_name do\n    :telemetry.execute([:event_namespace, :last_value], %{total: 123}, %{custom_metric: \"region\"})\n  end\nend\n```\n\nUltimately every list will get flattened which allows you to group metric modules under a single module such as\n\n```elixir\ndefmodule GraphQL.Request do\n  def metrics do\n    ...\n  end\nend\n\ndefmodule GraphQL.Complexity do\n  def metrics do\n    ...\n  end\nend\n\ndefmodule GraphQL do\n  def metrics, do: [GraphQL.Complexity.metrics(), GraphQL.Request.metrics()]\nend\n```\n\nFor more details on types you can check [telemetry_metrics_prometheus_core](https://hexdocs.pm/telemetry_metrics_prometheus_core/1.0.1/TelemetryMetricsPrometheus.Core.html)\nYou can also generate these custom metrics modules using `mix prometheus_telemetry.gen.metrics`\n\n#### Ecto Extras\nThis library hooks into [Ecto's adapter-specific telemetry events](https://hexdocs.pm/ecto/Ecto.Repo.html#module-adapter-specific-events). In order to correctly namespace events for your repo(s), you must pass an atom (or list of atoms) when injecting the metrics. E.g.: `PrometheusTelemetry.Metrics.Ecto.metrics(:my_ecto_app)` will produce corresponding metrics with the correct event_name of `[:my_ecto_app, :repo, :query]`.\n\n`PrometheusTelemetry.Metrics.Ecto.metrics_for_repo/1` and `PrometheusTelemetry.Metrics.Ecto.metrics_for_repos/1` can be used as a convenience for umbrellas with multiple repos and for deduplicating metrics\nfor replicas: \n\n```elixir\niex> PrometheusTelemetry.Metrics.Ecto.metrics_for_repo(MyEctoApp.Repo)\n[\n  %Telemetry.Metrics.Distribution{\n    description: \"Gets total time spent on query\",\n    event_name: [:my_ecto_app, :repo, :query],\n\t\t...\n  },\n  ...\n]\n\n```\n\nA few additional extras exist for Ecto, which include the ability to set the max query size before truncation\nas well as add a known module query which will be called with `shorten(query)`\n\nYou can set both of these via config, by default there's no known query module and the max query size is 150.\n\nThe other way to set the label for a query is directly in the `Repo.all` or `Actions.all` (if using [ecto_shorts](https://github.com/MikaAK/ecto_shorts))\n\nRepo:\n```elixir\nRepo.all(User, telemetry_options: [label: \"All Users\"])\n```\n\nEctoShorts:\n```elixir\nActions.find(User, params, telemetry_options: [label: \"Find User\"])\n```\n\n#### Generating Metrics Modules\nUsing the `mix prometheus_telemetry.gen.metrics` you can generate metrics modules instead of writing them manually\n\n```bash\n$ mix prometheus_telemetry.gen.metrics MyApp.Metrics.Type counter:event.name.measurement.count:event.name.count:count:tags:profile:region\n```\n\nThe format used is the following:\n```elixir\n : : : :tags: : \n```\n\nView the `Mix.Tasks.PrometheusTelemetry.Gen.Metrics` module for more details","ref":"PrometheusTelemetry.html#module-defining-custom-metrics"},{"type":"module","title":"Hiring - PrometheusTelemetry","doc":"Are you looking for a new gig?? We're looking for mid-level to senior level developers to join our team and continue growing our platform while building awesome software!\n\nCome join us at [Blitz.gg](https://blitz.gg/careers)\n\"","ref":"PrometheusTelemetry.html#module-hiring"},{"type":"module","title":"Supported Options - PrometheusTelemetry","doc":"* `:name` (`t:atom/0`) - Name for the prometheus telemetry supervisor The default value is `:prometheus_telemetry`.\n\n* `:exporter` (`t:keyword/0`) - Exporter config The default value is `[enabled?: false, opts: []]`.\n\n  * `:enabled?` (`t:boolean/0`) - The default value is `false`.\n\n  * `:opts` (`t:keyword/0`) - Exporter options The default value is `[]`.\n\n    * `:ip` (tuple of `t:non_neg_integer/0`, `t:non_neg_integer/0`, `t:non_neg_integer/0`, `t:non_neg_integer/0` values) - IP address to bind the exporter on The default value is `{0, 0, 0, 0}`.\n\n    * `:port` (`t:integer/0`) - Port to start the exporter on The default value is `4050`.\n\n    * `:protocol` - The default value is `:http`.\n\n* `:metrics` (list of `t:term/0`) - Metrics to start and aggregate that will ultimately end up in the exporter\n\n* `:periodic_measurements` (list of `t:term/0`) - Periodic metrics to start and aggregate that will ultimately end up in the exporter","ref":"PrometheusTelemetry.html#module-supported-options"},{"type":"function","title":"PrometheusTelemetry.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"PrometheusTelemetry.html#child_spec/1"},{"type":"function","title":"PrometheusTelemetry.get_metrics_string/0","doc":"","ref":"PrometheusTelemetry.html#get_metrics_string/0"},{"type":"function","title":"PrometheusTelemetry.get_metrics_string/1","doc":"","ref":"PrometheusTelemetry.html#get_metrics_string/1"},{"type":"function","title":"PrometheusTelemetry.list/0","doc":"","ref":"PrometheusTelemetry.html#list/0"},{"type":"function","title":"PrometheusTelemetry.list_prometheus_cores/1","doc":"","ref":"PrometheusTelemetry.html#list_prometheus_cores/1"},{"type":"function","title":"PrometheusTelemetry.poller_postfix/0","doc":"","ref":"PrometheusTelemetry.html#poller_postfix/0"},{"type":"function","title":"PrometheusTelemetry.start_link/1","doc":"","ref":"PrometheusTelemetry.html#start_link/1"},{"type":"module","title":"PrometheusTelemetry.MetricsExporterPlug","doc":"This is the exporter for prometheus that sets up metrics to be scraped\n\nIt uses /metrics as a route and is setup on port 4050 by default","ref":"PrometheusTelemetry.MetricsExporterPlug.html"},{"type":"function","title":"PrometheusTelemetry.MetricsExporterPlug.child_spec/1","doc":"","ref":"PrometheusTelemetry.MetricsExporterPlug.html#child_spec/1"},{"type":"module","title":"PrometheusTelemetry.Metrics.Cowboy","doc":"These metrics give you data around Cowboy, the low level web handler of phoenix\n\n  - `cowboy.request.count`\n  - `cowboy.request.early_error.count`\n  - `cowboy.request.exception.count`\n  - `cowboy.request.duration.milliseconds`","ref":"PrometheusTelemetry.Metrics.Cowboy.html"},{"type":"function","title":"PrometheusTelemetry.Metrics.Cowboy.metrics/0","doc":"","ref":"PrometheusTelemetry.Metrics.Cowboy.html#metrics/0"},{"type":"module","title":"PrometheusTelemetry.Metrics.Ecto","doc":"These metrics give you metrics around phoenix requests\n\n  - `ecto.query.total_time`\n  - `ecto.query.decode_time`\n  - `ecto.query.query_time`\n  - `ecto.query.idle_time`","ref":"PrometheusTelemetry.Metrics.Ecto.html"},{"type":"function","title":"PrometheusTelemetry.Metrics.Ecto.metrics/1","doc":"","ref":"PrometheusTelemetry.Metrics.Ecto.html#metrics/1"},{"type":"function","title":"PrometheusTelemetry.Metrics.Ecto.metrics_for_repo/1","doc":"","ref":"PrometheusTelemetry.Metrics.Ecto.html#metrics_for_repo/1"},{"type":"function","title":"PrometheusTelemetry.Metrics.Ecto.metrics_for_repos/1","doc":"","ref":"PrometheusTelemetry.Metrics.Ecto.html#metrics_for_repos/1"},{"type":"module","title":"PrometheusTelemetry.Metrics.Finch","doc":"","ref":"PrometheusTelemetry.Metrics.Finch.html"},{"type":"function","title":"PrometheusTelemetry.Metrics.Finch.metrics/0","doc":"","ref":"PrometheusTelemetry.Metrics.Finch.html#metrics/0"},{"type":"function","title":"PrometheusTelemetry.Metrics.Finch.pool_metrics/0","doc":"","ref":"PrometheusTelemetry.Metrics.Finch.html#pool_metrics/0"},{"type":"function","title":"PrometheusTelemetry.Metrics.Finch.request_metrics/0","doc":"","ref":"PrometheusTelemetry.Metrics.Finch.html#request_metrics/0"},{"type":"function","title":"PrometheusTelemetry.Metrics.Finch.send_receive_metrics/0","doc":"","ref":"PrometheusTelemetry.Metrics.Finch.html#send_receive_metrics/0"},{"type":"module","title":"PrometheusTelemetry.Metrics.GraphQL","doc":"These metrics give you metrics around Absinthes GraphQL requests\n\n  - `graphql.request.count`\n  - `graphql.execute.duration.milliseconds`\n  - `graphql.subscription.duration.milliseconds`\n  - `graphql.resolve.duration.milliseconds`\n  - `graphql.middleware.batch.duration.milliseconds`","ref":"PrometheusTelemetry.Metrics.GraphQL.html"},{"type":"function","title":"PrometheusTelemetry.Metrics.GraphQL.metrics/0","doc":"","ref":"PrometheusTelemetry.Metrics.GraphQL.html#metrics/0"},{"type":"function","title":"PrometheusTelemetry.Metrics.GraphQL.observe_complexity/2","doc":"","ref":"PrometheusTelemetry.Metrics.GraphQL.html#observe_complexity/2"},{"type":"module","title":"PrometheusTelemetry.Metrics.Oban","doc":"These metrics give you metrics around Oban jobs\n\n    - `oban.job.started.count`\n    - `oban.job.duration.millisecond`\n    - `oban.job.queue_time.millisecond`\n    - `oban.job.exception.duration.millisecond`\n    - `oban.job.exception.queue_time.millisecond`","ref":"PrometheusTelemetry.Metrics.Oban.html"},{"type":"function","title":"PrometheusTelemetry.Metrics.Oban.metrics/0","doc":"","ref":"PrometheusTelemetry.Metrics.Oban.html#metrics/0"},{"type":"module","title":"PrometheusTelemetry.Metrics.Phoenix","doc":"These metrics give you metrics around phoenix requests\n\n  - `http_request.duration.milliseconds`\n  - `phoenix.endpoint_call.duration.milliseconds`\n  - `phoenix.controller_call.duration.milliseconds`\n  - `phoenix.controller_error_rendered.duration.milliseconds`\n  - `phoenix.channel_join.duration.milliseconds_bucket`\n  - `phoenix.channel_receive.duration.milliseconds`","ref":"PrometheusTelemetry.Metrics.Phoenix.html"},{"type":"function","title":"PrometheusTelemetry.Metrics.Phoenix.metrics/0","doc":"","ref":"PrometheusTelemetry.Metrics.Phoenix.html#metrics/0"},{"type":"module","title":"PrometheusTelemetry.Metrics.Swoosh","doc":"These metrics give you metrics around swoosh emails\n\n  - `swoosh.deliver.request_count`\n  - `swoosh.deliver.request_duration`\n  - `swoosh.deliver.exception_count`\n  - `swoosh.deliver_many.request_count`\n  - `swoosh.deliver_many.request_duration`\n  - `swoosh.deliver_many.exception_count`","ref":"PrometheusTelemetry.Metrics.Swoosh.html"},{"type":"function","title":"PrometheusTelemetry.Metrics.Swoosh.metrics/0","doc":"","ref":"PrometheusTelemetry.Metrics.Swoosh.html#metrics/0"},{"type":"module","title":"PrometheusTelemetry.Metrics.VM","doc":"These metrics give you some basic VM statistics from erlang, this includes:\n\n  - `erlang.vm.memory`\n  - `erlang.vm.run_queue.total`\n  - `erlang.vm.run_queue.cpu`\n  - `erlang.vm.run_queue.io`","ref":"PrometheusTelemetry.Metrics.VM.html"},{"type":"function","title":"PrometheusTelemetry.Metrics.VM.metrics/0","doc":"","ref":"PrometheusTelemetry.Metrics.VM.html#metrics/0"}],"content_type":"text/markdown","proglang":"elixir","producer":{"name":"ex_doc","version":"0.37.3"}}